package
Version:
v0.2.14
Opens a new window with list of versions in this module.
Published: Feb 28, 2026
License: MIT
Opens a new window with license information.
Imports: 21
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Execute runs the root command.
type BuildInfo struct {
Version string `json:"version"`
Commit string `json:"commit"`
Date string `json:"date"`
GoVersion string `json:"goVersion"`
}
BuildInfo holds version and build metadata.
type ExitError struct {
Code int
}
ExitError signals a non-zero exit code without calling os.Exit directly.
This allows tests to observe exit codes without killing the test process.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.